const mongoose = require('mongoose');
const bcrypt = require('bcrypt');
const libs = `${process.cwd()}/libs`;
const log = require(`${libs}/log`)(module);
const Schema = mongoose.Schema;

// set up a mongoose model
var UserSchema = new Schema({
    email: {
        type: String,
        unique: true,
        required: [true, 'O campo Email é obrigatório.']
    },
    password: {
        type: String,
        required: [true, 'O campo Senha é obrigatório.']
    },
    name: {
        type: String,
        required: [true, 'O campo Nome é obrigatório.']
    },
    cpf:{
        type: String,
        unique: true,
        required: [true, 'O campo CPF é obrigatório.']
    },
    schooling: {
        type: String,
        required: [true, 'O campo Escolaridade é obrigatório.']
    },
    course: {
        type: String,
    },
    segment: {
        type: String,
        required: [true, 'O campo Segmento é obrigatório.']
    },
    role: {
        type: String,
        required: [true, 'O campo Função é obrigatório.']
    },
    institution_name: {
        type: String,
        required: [true, 'O campo Instituição em que trabalha é obrigatório.']
    },
    state: {
        type: String,
        required: [true, 'O campo Estado é obrigatório.']
    },
    city: {
        type: String,
        required: [true, 'O campo Cidade é obrigatório.']
    },
    receive_emails: {
        type: Boolean
    }

});

UserSchema.pre('save', function (next) {
    var user = this;
    if (this.isModified('password') || this.isNew) {
        bcrypt.genSalt(10, function (err, salt) {
            if (err) {
                return next(err);
            }
            bcrypt.hash(user.password, salt, function (err, hash) {
                if (err) {
                    return next(err);
                }
                user.password = hash;
                next();
            });
        });
    } else {
        return next();
    }
});

UserSchema.methods.comparePassword = function (passw, cb) {
    bcrypt.compare(passw, this.password, function (err, isMatch) {
        if (err) {
            return cb(err);
        }
        cb(null, isMatch);
    });
};

module.exports = mongoose.model('User', UserSchema);
